@@ -1,8 +1,9 @@
 #!/usr/bin/python3
 
+from contextlib import suppress
 from debian.copyright import License
-from lintian_brush.copyright import CopyrightUpdater, NotMachineReadableError
-from lintian_brush.fixer import report_result
+from debmutate.copyright import CopyrightEditor, NotMachineReadableError
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 from lintian_brush.licenses import load_spdx_data
 
 RENAMES = {k.lower(): v for k, v in {
@@ -46,15 +47,15 @@ def fix_spaces(copyright):
             names.append(name)
         newsynopsis = ' or '.join(names)
         if newsynopsis != paragraph.license.synopsis:
+            fixed_lintian_tag(
+                'source', 'space-in-std-shortname-in-dep5-copyright',
+                '%s (line XX)' % paragraph.license.synopsis)
             paragraph.license = License(newsynopsis, paragraph.license.text)
 
 
-try:
-    with CopyrightUpdater() as updater:
-        fix_spaces(updater.copyright)
-except (FileNotFoundError, NotMachineReadableError):
-    pass
+with suppress(FileNotFoundError, NotMachineReadableError), \
+        CopyrightEditor() as updater:
+    fix_spaces(updater.copyright)
 
 report_result(
-    'Replace spaces in short license names with dashes.',
-    fixed_lintian_tags=['space-in-std-shortname-in-dep5-copyright'])
+    'Replace spaces in short license names with dashes.')
